=============================
``psyclone.psyir.nodes.call``
=============================

.. automodule:: psyclone.psyir.nodes.call

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.nodes.call
